/**
 * @module Send
 * @license MIT
 * @author nuintun
 */
import { Context } from 'koa';
export interface Options {
  etag?: boolean;
  cacheControl?: string;
  acceptRanges?: boolean;
  lastModified?: boolean;
  ignore?: (path: string) => boolean;
}
/**
 * @class Send
 */
export default class Send {
  private ctx;
  private root;
  private options;
  private path;
  /**
   * @constructor
   * @param {Context} ctx
   * @param {string} root
   * @param {Options} options
   */
  constructor(ctx: Context, root: string | undefined, options: Options);
  /**
   * @method isConditionalGET
   * @returns {boolean}
   */
  private isConditionalGET;
  /**
   * @method isPreconditionFailure
   * @returns {boolean}
   */
  private isPreconditionFailure;
  /**
   * @method isRangeFresh
   * @returns {boolean}
   */
  private isRangeFresh;
  /**
   * @method isIgnore
   * @param {string} path
   * @returns {boolean}
   */
  private isIgnore;
  /**
   * @method parseRange
   * @param {Stats} stats
   * @returns {Ranges}
   */
  private parseRange;
  /**
   * @method setupHeaders
   * @param {string} path
   * @param {Stats} stats
   */
  private setupHeaders;
  /**
   * @method read
   * @param {string} path
   * @param {Range} range
   * @param {PassThrough} buffer
   * @param {boolean} end
   * @returns {Promise<true>}
   */
  private read;
  /**
   * @method send
   * @param {string} path
   * @param {Range[]} ranges
   */
  private send;
  /**
   * @method response
   * @returns {Promise<boolean>}
   */
  response(): Promise<boolean>;
}
