/**
 * @module utils
 * @license MIT
 * @author nuintun
 */
/// <reference types="node" />
import { Stats } from 'fs';
/**
 * @function isOutRoot
 * @description Test path is out of bound of root
 * @param {string} path
 * @param {string} root
 * @returns {boolean}
 */
export declare function isOutRoot(path: string, root: string): boolean;
/**
 * @function unixify
 * @description Convert path separators to posix/unix-style forward slashes
 * @param {string} path
 * @returns {string}
 */
export declare function unixify(path: string): string;
/**
 * @function decodeURI
 * @description Decode URI component.
 * @param {string} URI
 * @returns {string|-1}
 */
export declare function decodeURI(URI: string): string | -1;
/**
 * @function boundaryGenerator
 * @description Create boundary
 * @returns {string}
 */
export declare function boundaryGenerator(): string;
/**
 * @function fstat
 * @param {string} path
 * @returns {Promise<Stats>}
 */
export declare function fstat(path: string): Promise<Stats>;
/**
 * @function hasTrailingSlash
 * @param {string} path
 * @returns {boolean}
 */
export declare function hasTrailingSlash(path: string): boolean;
/**
 * @function isETagFresh
 * @param {string} match
 * @param {string} etag
 * @returns {boolean}
 */
export declare function isETagFresh(match: string, etag: string): boolean;
/**
 * @function isETag
 * @param {string} etag
 * @returns {boolean}
 */
export declare function isETag(etag: string): boolean;
